@@ -601,7 +601,7 @@ class DynamoDBModel(object):
         return (
             cls.from_dict(d)
             for d in res
-            if d['key'] != MAGIC_KEY or cls.__schema__[hash_key_name] != autoincrement_int
+            if d[hash_key_name] != MAGIC_KEY or cls.__schema__[hash_key_name] != autoincrement_int
         )
 
     def to_db_dict(self):
